@@ -11,7 +11,7 @@ from itertools import cycle
 from inspect import isclass
 import logging
 
-__version__ = "0.2.6"
+__version__ = "0.2.12"
 
 EXIF_DATE_TAG = "Image DateTime"
 EXIF_DATE_FMT = "%Y:%m:%d %H:%M:%S"
@@ -21,10 +21,11 @@ TS_V2_FMT = ("%Y/%Y_%m/%Y_%m_%d/%Y_%m_%d_%H/"
              "{tsname:s}_%Y_%m_%d_%H_%M_%S_{n:02d}.{ext:s}")
 TS_DATE_FMT = "%Y_%m_%d_%H_%M_%S"
 TS_FMT = TS_V1_FMT
-TS_NAME_FMT = "{expt:s}-{loc:s}~{res:s}-{step:s}"
+TS_NAME_FMT = "{expt:s}-{loc:s}-C{cam:02d}~{res:s}-{step:s}"
 FULLRES_CONSTANTS = {"original", "orig", "fullres"}
 IMAGE_TYPE_CONSTANTS = {"raw", "jpg"}
 RAW_FORMATS = {"cr2", "nef", "tif", "tiff"}
+IMAGE_SUBFOLDERS = {"raw", "jpg", "png", "tiff", "nef", "cr2"}
 DATE_NOW_CONSTANTS = {"now", "current"}
 CLI_OPTS = """
 USAGE:
@@ -54,6 +55,7 @@ FIELDS = {
     'use': 'USE',
     'location': 'LOCATION',
     'expt': 'CURRENT_EXPT',
+    'cam_num': 'CAM_NUM',
     'source': 'SOURCE',
     'destination': 'DESTINATION',
     'archive_dest': 'ARCHIVE_DEST',
@@ -74,6 +76,7 @@ FIELD_ORDER = [
     'use',
     'location',
     'expt',
+    'cam_num',
     'source',
     'destination',
     'archive_dest',
@@ -203,6 +206,7 @@ def validate_camera(camera):
         Required(FIELDS["use"]): bool_str,
         Required(FIELDS["destination"]): path_exists,
         Required(FIELDS["expt"]): str,
+        Required(FIELDS["cam_num"]): num_str,
         Required(FIELDS["expt_end"]): date,
         Required(FIELDS["expt_start"]): date,
         Required(FIELDS["image_types"]): image_type_str,
@@ -300,6 +304,7 @@ def make_timestream_name(camera, res="fullres", step="orig"):
     return TS_NAME_FMT.format(
         expt=camera[FIELDS["expt"]],
         loc=camera[FIELDS["location"]],
+        cam=camera[FIELDS["cam_num"]],
         res=res,
         step=step
     )
@@ -493,15 +498,25 @@ def find_image_files(camera):
             ext_dir = "raw"
         else:
             ext_dir = ext
-        src = path.join(camera[FIELDS["source"]], ext_dir)
+        src = camera[FIELDS["source"]]
+        lst = os.listdir(src)
+        lst = filter(lambda x: not x.startswith(".") and not x.startswith('_'),
+                     lst)
+        log.debug("List of src valid subdirs is {}".format(lst))
+        for node in lst:
+            log.debug("Found src subdir {}".format(node))
+            if node.lower() == ext:
+                src = path.join(src, node)
+                break
+        log.info("Walking from {} to find images".format(src))
         walk = os.walk(src, topdown=True)
         for cur_dir, dirs, files in walk:
-            if len(dirs) > 0:
-                for d in dirs:
-                    if not d.startswith("_"):
-                        log.error("Souce directory has too many subdirs.A")
-                        # TODO: Is raising here a good idea?
-                        #raise ValueError("too many subdirs")
+            for dir in dirs:
+                if dir.lower() not in IMAGE_SUBFOLDERS and \
+                        not dir.startswith("_"):
+                    log.error("Souce directory has too many subdirs.A")
+                    # TODO: Is raising here a good idea?
+                    #raise ValueError("too many subdirs")
             for fle in files:
                 this_ext = path.splitext(fle)[-1].lower().strip(".")
                 if this_ext == ext or ext == "raw" and this_ext in RAW_FORMATS:
@@ -585,18 +600,12 @@ def main(opts):
             last_date = None
             subsec = 0
             count = 0
-            if n_cam_images < 100:
-                each = 10
-            else:
-                each = 50
             # TODO: sort out the whole subsecond clusterfuck
             if "-1" in opts and opts["-1"]:
                 log.info("Using 1 process (What is this? Fucking 1990?)")
                 for image in images:
                     count += 1
-                    if count % each == 0:
-                        print("Processed {: 5d} Images".format(count),
-                              end='\r')
+                    print("Processed {: 5d} Images".format(count), end='\r')
                     process_image((image, camera, ext))
             else:
                 from multiprocessing import Pool, cpu_count
@@ -613,15 +622,13 @@ def main(opts):
                 pool = Pool(threads)
                 for _ in pool.imap(process_image, args):
                     count += 1
-                    if count % each == 0:
-                        print("Processed {: 5d} Images".format(count),
-                              end='\r')
+                    print("Processed {: 5d} Images".format(count), end='\r')
                 pool.close()
                 pool.join()
-            print("Processed {: 5d} Images".format(count))
+            print("Processed {: 5d} Images. Finished this cam!".format(count))
     secs_taken = time() - start_time
     print("\nProcessed a total of {0} images in {1:.2f} seconds".format(
-        n_images, secs_taken))
+          n_images, secs_taken))
 
 
 if __name__ == "__main__":
